/* 
  SCLModelSwarm.h

  Barry McMullin <mcmullin@eeng.dcu.ie>
  27-SEP-1996

*/

#import <simtoolsgui.h>
#import <simtoolsgui/GUISwarm.h>

#import "VNneighbor.h"
#import "DiscreteToroid.h"


@interface SCLModelSwarm : GUISwarm {
  id probeDisplay;
  id modelActions;
  id modelSchedule;
}


-step;
-setStateStopped;

@end
